console

package
v0.0.0-...-4502610 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2025 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateIndexes

func CreateIndexes(collectionName string, models []mongo.IndexModel) error

CreateIndexes - Allows creating mongoDB indexes Ideally to be used as console command

func RunRollUp

func RunRollUp() error

RunRollUp - Allow running migrations from configured directory Ideally to be used as console command

func RunRollback

func RunRollback() error

RunRollback - Allow running rollbacks from configured directory Ideally to be used as console command

func StartServer

func StartServer(router *ddTracerMux.Router)

StartServer - Starts the web server using a fully qualified mux router

Types

This section is empty.

Jump to